==> oci-java-sdk-shaded-full-3.40.0-sources.jar: com/oracle/bmc/ailanguage/requests/BatchDetectDominantLanguageRequest.java <==
/**
 * Copyright (c) 2016, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
package com.oracle.bmc.ailanguage.requests;

import com.oracle.bmc.ailanguage.model.*;
/**
 * <b>Example: </b>Click <a
 * href="https://docs.cloud.oracle.com/en-us/iaas/tools/java-sdk-examples/3.40.0/ailanguage/BatchDetectDominantLanguageExample.java.html"
 * target="_blank" rel="noopener noreferrer">here</a> to see how to use
 * BatchDetectDominantLanguageRequest.
 */
@jakarta.annotation.Generated(value = "OracleSDKGenerator", comments = "API Version: 20221001")
public class BatchDetectDominantLanguageRequest
        extends com.oracle.bmc.requests.BmcRequest<
                com.oracle.bmc.ailanguage.model.BatchDetectDominantLanguageDetails> {

    /** The details to make a language detection detect call. */
    private com.oracle.bmc.ailanguage.model.BatchDetectDominantLanguageDetails
            batchDetectDominantLanguageDetails;

    /** The details to make a language detection detect call. */
    public com.oracle.bmc.ailanguage.model.BatchDetectDominantLanguageDetails
            getBatchDetectDominantLanguageDetails() {
        return batchDetectDominantLanguageDetails;
    }
    /** The client request ID for tracing. */
    private String opcRequestId;

    /** The client request ID for tracing. */
    public String getOpcRequestId() {
        return opcRequestId;
    }

    /**
     * Alternative accessor for the body parameter.
     *
     * @return body parameter
     */
    @Override
    @com.oracle.bmc.InternalSdk
    public com.oracle.bmc.ailanguage.model.BatchDetectDominantLanguageDetails getBody$() {
        return batchDetectDominantLanguageDetails;
    }

    public static class Builder
            implements com.oracle.bmc.requests.BmcRequest.Builder<
                    BatchDetectDominantLanguageRequest,
                    com.oracle.bmc.ailanguage.model.BatchDetectDominantLanguageDetails> {
        private com.oracle.bmc.http.client.RequestInterceptor invocationCallback = null;
        private com.oracle.bmc.retrier.RetryConfiguration retryConfiguration = null;

        /** The details to make a language detection detect call. */
        private com.oracle.bmc.ailanguage.model.BatchDetectDominantLanguageDetails
                batchDetectDominantLanguageDetails = null;

        /**
         * The details to make a language detection detect call.
         *
         * @param batchDetectDominantLanguageDetails the value to set
         * @return this builder instance
         */
        public Builder batchDetectDominantLanguageDetails(
                com.oracle.bmc.ailanguage.model.BatchDetectDominantLanguageDetails
                        batchDetectDominantLanguageDetails) {
            this.batchDetectDominantLanguageDetails = batchDetectDominantLanguageDetails;
            return this;
        }

        /** The client request ID for tracing. */
        private String opcRequestId = null;

        /**
         * The client request ID for tracing.
         *
         * @param opcRequestId the value to set
         * @return this builder instance
         */
        public Builder opcRequestId(String opcRequestId) {
            this.opcRequestId = opcRequestId;
            return this;
        }

        /**
         * Set the invocation callback for the request to be built.
         *
         * @param invocationCallback the invocation callback to be set for the request
         * @return this builder instance
         */
        public Builder invocationCallback(
                com.oracle.bmc.http.client.RequestInterceptor invocationCallback) {
            this.invocationCallback = invocationCallback;
            return this;
        }

        /**
         * Set the retry configuration for the request to be built.
         *
         * @param retryConfiguration the retry configuration to be used for the request
         * @return this builder instance
         */
        public Builder retryConfiguration(
                com.oracle.bmc.retrier.RetryConfiguration retryConfiguration) {
            this.retryConfiguration = retryConfiguration;
            return this;
        }

        /**
         * Copy method to populate the builder with values from the given instance.
         *
         * @return this builder instance
         */
        public Builder copy(BatchDetectDominantLanguageRequest o) {
            batchDetectDominantLanguageDetails(o.getBatchDetectDominantLanguageDetails());
            opcRequestId(o.getOpcRequestId());
            invocationCallback(o.getInvocationCallback());
            retryConfiguration(o.getRetryConfiguration());
            return this;
        }

        /**
         * Build the instance of BatchDetectDominantLanguageRequest as configured by this builder
         *
         * <p>Note that this method takes calls to {@link
         * Builder#invocationCallback(com.oracle.bmc.http.client.RequestInterceptor)} into account,
         * while the method {@link Builder#buildWithoutInvocationCallback} does not.
         *
         * <p>This is the preferred method to build an instance.
         *
         * @return instance of BatchDetectDominantLanguageRequest
         */
        public BatchDetectDominantLanguageRequest build() {
            BatchDetectDominantLanguageRequest request = buildWithoutInvocationCallback();
            request.setInvocationCallback(invocationCallback);
            request.setRetryConfiguration(retryConfiguration);
            return request;
        }

        /**
         * Alternative setter for the body parameter.
         *
         * @param body the body parameter
         * @return this builder instance
         */
        @com.oracle.bmc.InternalSdk
        public Builder body$(
                com.oracle.bmc.ailanguage.model.BatchDetectDominantLanguageDetails body) {
            batchDetectDominantLanguageDetails(body);
            return this;
        }

        /**
         * Build the instance of BatchDetectDominantLanguageRequest as configured by this builder
         *
         * <p>Note that this method does not take calls to {@link
         * Builder#invocationCallback(com.oracle.bmc.http.client.RequestInterceptor)} into account,
         * while the method {@link Builder#build} does
         *
         * @return instance of BatchDetectDominantLanguageRequest
         */
        public BatchDetectDominantLanguageRequest buildWithoutInvocationCallback() {
            BatchDetectDominantLanguageRequest request = new BatchDetectDominantLanguageRequest();
            request.batchDetectDominantLanguageDetails = batchDetectDominantLanguageDetails;
            request.opcRequestId = opcRequestId;
            return request;
            // new BatchDetectDominantLanguageRequest(batchDetectDominantLanguageDetails,
            // opcRequestId);
        }
    }

    /**
     * Return an instance of {@link Builder} that allows you to modify request properties.
     *
     * @return instance of {@link Builder} that allows you to modify request properties.
     */
    public Builder toBuilder() {
        return new Builder()
                .batchDetectDominantLanguageDetails(batchDetectDominantLanguageDetails)
                .opcRequestId(opcRequestId);
    }

    /**
     * Return a new builder for this request object.
     *
     * @return builder for the request object
     */
    public static Builder builder() {
        return new Builder();
    }

    @Override
    public String toString() {
        java.lang.StringBuilder sb = new java.lang.StringBuilder();
        sb.append("(");
        sb.append("super=").append(super.toString());
        sb.append(",batchDetectDominantLanguageDetails=")
                .append(String.valueOf(this.batchDetectDominantLanguageDetails));
        sb.append(",opcRequestId=").append(String.valueOf(this.opcRequestId));
        sb.append(")");
        return sb.toString();
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (!(o instanceof BatchDetectDominantLanguageRequest)) {
            return false;
        }

        BatchDetectDominantLanguageRequest other = (BatchDetectDominantLanguageRequest) o;
        return super.equals(o)
                && java.util.Objects.equals(
                        this.batchDetectDominantLanguageDetails,
                        other.batchDetectDominantLanguageDetails)
                && java.util.Objects.equals(this.opcRequestId, other.opcRequestId);
    }

    @Override
    public int hashCode() {
        final int PRIME = 59;
        int result = super.hashCode();
        result =
                (result * PRIME)
                        + (this.batchDetectDominantLanguageDetails == null
                                ? 43
                                : this.batchDetectDominantLanguageDetails.hashCode());
        result = (result * PRIME) + (this.opcRequestId == null ? 43 : this.opcRequestId.hashCode());
        return result;
    }
}

==> oci-java-sdk-shaded-full-3.48.0-sources.jar: com/oracle/bmc/ailanguage/requests/BatchDetectDominantLanguageRequest.java <==
/**
 * Copyright (c) 2016, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
package com.oracle.bmc.ailanguage.requests;

import com.oracle.bmc.ailanguage.model.*;
/**
 * <b>Example: </b>Click <a
 * href="https://docs.cloud.oracle.com/en-us/iaas/tools/java-sdk-examples/latest/ailanguage/BatchDetectDominantLanguageExample.java.html"
 * target="_blank" rel="noopener noreferrer">here</a> to see how to use
 * BatchDetectDominantLanguageRequest.
 */
@jakarta.annotation.Generated(value = "OracleSDKGenerator", comments = "API Version: 20221001")
public class BatchDetectDominantLanguageRequest
        extends com.oracle.bmc.requests.BmcRequest<
                com.oracle.bmc.ailanguage.model.BatchDetectDominantLanguageDetails> {

    /** The details to make a language detection detect call. */
    private com.oracle.bmc.ailanguage.model.BatchDetectDominantLanguageDetails
            batchDetectDominantLanguageDetails;

    /** The details to make a language detection detect call. */
    public com.oracle.bmc.ailanguage.model.BatchDetectDominantLanguageDetails
            getBatchDetectDominantLanguageDetails() {
        return batchDetectDominantLanguageDetails;
    }
    /** The client request ID for tracing. */
    private String opcRequestId;

    /** The client request ID for tracing. */
    public String getOpcRequestId() {
        return opcRequestId;
    }

    /**
     * Alternative accessor for the body parameter.
     *
     * @return body parameter
     */
    @Override
    @com.oracle.bmc.InternalSdk
    public com.oracle.bmc.ailanguage.model.BatchDetectDominantLanguageDetails getBody$() {
        return batchDetectDominantLanguageDetails;
    }

    public static class Builder
            implements com.oracle.bmc.requests.BmcRequest.Builder<
                    BatchDetectDominantLanguageRequest,
                    com.oracle.bmc.ailanguage.model.BatchDetectDominantLanguageDetails> {
        private com.oracle.bmc.http.client.RequestInterceptor invocationCallback = null;
        private com.oracle.bmc.retrier.RetryConfiguration retryConfiguration = null;

        /** The details to make a language detection detect call. */
        private com.oracle.bmc.ailanguage.model.BatchDetectDominantLanguageDetails
                batchDetectDominantLanguageDetails = null;

        /**
         * The details to make a language detection detect call.
         *
         * @param batchDetectDominantLanguageDetails the value to set
         * @return this builder instance
         */
        public Builder batchDetectDominantLanguageDetails(
                com.oracle.bmc.ailanguage.model.BatchDetectDominantLanguageDetails
                        batchDetectDominantLanguageDetails) {
            this.batchDetectDominantLanguageDetails = batchDetectDominantLanguageDetails;
            return this;
        }

        /** The client request ID for tracing. */
        private String opcRequestId = null;

        /**
         * The client request ID for tracing.
         *
         * @param opcRequestId the value to set
         * @return this builder instance
         */
        public Builder opcRequestId(String opcRequestId) {
            this.opcRequestId = opcRequestId;
            return this;
        }

        /**
         * Set the invocation callback for the request to be built.
         *
         * @param invocationCallback the invocation callback to be set for the request
         * @return this builder instance
         */
        public Builder invocationCallback(
                com.oracle.bmc.http.client.RequestInterceptor invocationCallback) {
            this.invocationCallback = invocationCallback;
            return this;
        }

        /**
         * Set the retry configuration for the request to be built.
         *
         * @param retryConfiguration the retry configuration to be used for the request
         * @return this builder instance
         */
        public Builder retryConfiguration(
                com.oracle.bmc.retrier.RetryConfiguration retryConfiguration) {
            this.retryConfiguration = retryConfiguration;
            return this;
        }

        /**
         * Copy method to populate the builder with values from the given instance.
         *
         * @return this builder instance
         */
        public Builder copy(BatchDetectDominantLanguageRequest o) {
            batchDetectDominantLanguageDetails(o.getBatchDetectDominantLanguageDetails());
            opcRequestId(o.getOpcRequestId());
            invocationCallback(o.getInvocationCallback());
            retryConfiguration(o.getRetryConfiguration());
            return this;
        }

        /**
         * Build the instance of BatchDetectDominantLanguageRequest as configured by this builder
         *
         * <p>Note that this method takes calls to {@link
         * Builder#invocationCallback(com.oracle.bmc.http.client.RequestInterceptor)} into account,
         * while the method {@link Builder#buildWithoutInvocationCallback} does not.
         *
         * <p>This is the preferred method to build an instance.
         *
         * @return instance of BatchDetectDominantLanguageRequest
         */
        public BatchDetectDominantLanguageRequest build() {
            BatchDetectDominantLanguageRequest request = buildWithoutInvocationCallback();
            request.setInvocationCallback(invocationCallback);
            request.setRetryConfiguration(retryConfiguration);
            return request;
        }

        /**
         * Alternative setter for the body parameter.
         *
         * @param body the body parameter
         * @return this builder instance
         */
        @com.oracle.bmc.InternalSdk
        public Builder body$(
                com.oracle.bmc.ailanguage.model.BatchDetectDominantLanguageDetails body) {
            batchDetectDominantLanguageDetails(body);
            return this;
        }

        /**
         * Build the instance of BatchDetectDominantLanguageRequest as configured by this builder
         *
         * <p>Note that this method does not take calls to {@link
         * Builder#invocationCallback(com.oracle.bmc.http.client.RequestInterceptor)} into account,
         * while the method {@link Builder#build} does
         *
         * @return instance of BatchDetectDominantLanguageRequest
         */
        public BatchDetectDominantLanguageRequest buildWithoutInvocationCallback() {
            BatchDetectDominantLanguageRequest request = new BatchDetectDominantLanguageRequest();
            request.batchDetectDominantLanguageDetails = batchDetectDominantLanguageDetails;
            request.opcRequestId = opcRequestId;
            return request;
            // new BatchDetectDominantLanguageRequest(batchDetectDominantLanguageDetails,
            // opcRequestId);
        }
    }

    /**
     * Return an instance of {@link Builder} that allows you to modify request properties.
     *
     * @return instance of {@link Builder} that allows you to modify request properties.
     */
    public Builder toBuilder() {
        return new Builder()
                .batchDetectDominantLanguageDetails(batchDetectDominantLanguageDetails)
                .opcRequestId(opcRequestId);
    }

    /**
     * Return a new builder for this request object.
     *
     * @return builder for the request object
     */
    public static Builder builder() {
        return new Builder();
    }

    @Override
    public String toString() {
        java.lang.StringBuilder sb = new java.lang.StringBuilder();
        sb.append("(");
        sb.append("super=").append(super.toString());
        sb.append(",batchDetectDominantLanguageDetails=")
                .append(String.valueOf(this.batchDetectDominantLanguageDetails));
        sb.append(",opcRequestId=").append(String.valueOf(this.opcRequestId));
        sb.append(")");
        return sb.toString();
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (!(o instanceof BatchDetectDominantLanguageRequest)) {
            return false;
        }

        BatchDetectDominantLanguageRequest other = (BatchDetectDominantLanguageRequest) o;
        return super.equals(o)
                && java.util.Objects.equals(
                        this.batchDetectDominantLanguageDetails,
                        other.batchDetectDominantLanguageDetails)
                && java.util.Objects.equals(this.opcRequestId, other.opcRequestId);
    }

    @Override
    public int hashCode() {
        final int PRIME = 59;
        int result = super.hashCode();
        result =
                (result * PRIME)
                        + (this.batchDetectDominantLanguageDetails == null
                                ? 43
                                : this.batchDetectDominantLanguageDetails.hashCode());
        result = (result * PRIME) + (this.opcRequestId == null ? 43 : this.opcRequestId.hashCode());
        return result;
    }
}
